<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>MX Package Installer</source>
        <translation>MX-Instalador de Pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplicações seleccionadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Package</source>
        <translation>Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="653"/>
        <location filename="../mainwindow.ui" line="975"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="619"/>
        <location filename="../mainwindow.ui" line="944"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Instalar/Desinstalar aplicações/pacotes&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Os itens sombreados já estão instalados.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Debian Stable Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="889"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrar pacotes pelo estado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="567"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="892"/>
        <location filename="../mainwindow.ui" line="896"/>
        <location filename="../mainwindow.cpp" line="2188"/>
        <source>All packages</source>
        <translation>Todos os pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="901"/>
        <location filename="../mainwindow.cpp" line="2202"/>
        <source>Installed</source>
        <translation>Instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="581"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.cpp" line="2200"/>
        <source>Upgradable</source>
        <translation>Actualizáveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="586"/>
        <location filename="../mainwindow.ui" line="911"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2167"/>
        <location filename="../mainwindow.cpp" line="2204"/>
        <location filename="../mainwindow.cpp" line="2293"/>
        <source>Not installed</source>
        <translation>Não instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Package Name</source>
        <translation>Nome do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="648"/>
        <location filename="../mainwindow.ui" line="970"/>
        <location filename="../mainwindow.ui" line="1243"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="680"/>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Total packages:</source>
        <translation>Total de pacotes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1032"/>
        <source>Installed:</source>
        <translation>Instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <location filename="../mainwindow.ui" line="740"/>
        <location filename="../mainwindow.ui" line="1062"/>
        <source>Upgradable:</source>
        <translation>Actualizáveis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="1313"/>
        <source>Upgrade All</source>
        <translation>Actualizar Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1089"/>
        <source>Hide library and developer packages</source>
        <translation>Ocultar pacotes de bibliotecas e de desenvolvedor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="1111"/>
        <source>Refresh list</source>
        <translation>Recarregar a lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="919"/>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Os itens sombreados já estão instalados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <location filename="../mainwindow.ui" line="536"/>
        <location filename="../mainwindow.ui" line="856"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Pacote actualizável. Há uma versão mais recente disponível nos repositórios.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>MX Test Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Debian Backports</source>
        <translation>Debian Backports Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Flatpaks</source>
        <translation>Pacotes flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1159"/>
        <location filename="../mainwindow.ui" line="1163"/>
        <location filename="../mainwindow.cpp" line="2148"/>
        <source>All apps</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <location filename="../mainwindow.cpp" line="2153"/>
        <source>All runtimes</source>
        <translation>Software &apos;runtime&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <location filename="../mainwindow.cpp" line="2158"/>
        <source>All available</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1178"/>
        <location filename="../mainwindow.cpp" line="2146"/>
        <location filename="../mainwindow.cpp" line="2288"/>
        <source>Installed apps</source>
        <translation>Aplicações instaladas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1183"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <source>Installed runtimes</source>
        <translation>Software &apos;runtime&apos; instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Short Name</source>
        <translation>Nome curto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1238"/>
        <source>Full Package Name</source>
        <translation>Nome completo do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Total items </source>
        <translation>Total de itens </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1306"/>
        <source>Installed apps:</source>
        <translation>Aplicações instaladas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Advanced</source>
        <translation>Gestão avançada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1389"/>
        <source>Total installed size:</source>
        <translation>Total instalado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <location filename="../mainwindow.ui" line="1410"/>
        <source>For all users</source>
        <translation>Para todos os utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1415"/>
        <source>For current user</source>
        <translation>Para o presente utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1433"/>
        <source>Remote (repo):</source>
        <translation>Repositório remoto:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1476"/>
        <location filename="../mainwindow.cpp" line="1975"/>
        <location filename="../mainwindow.cpp" line="2101"/>
        <source>Console Output</source>
        <translation>Processamento em Consola/Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Enter</source>
        <translation>Introduzir/Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1493"/>
        <source>Respond here, or just press Enter</source>
        <translation>Responder aqui ou premir Introduzir/Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1556"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1572"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1575"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1582"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1630"/>
        <source>Display help </source>
        <translation>Mostrar a ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1640"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1656"/>
        <location filename="../mainwindow.cpp" line="1878"/>
        <location filename="../mainwindow.cpp" line="2282"/>
        <location filename="../mainwindow.cpp" line="2285"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1663"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1682"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1685"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Uninstalling packages...</source>
        <translation>A desinstalar pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Running post-uninstall operations...</source>
        <translation>A executar operações pós-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Refreshing sources...</source>
        <translation>A actualizar as origens...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="1946"/>
        <location filename="../mainwindow.cpp" line="1966"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Houve um problema ao actualizar as origens. Algumas podem não ter fornecido actualizações. Para mais informação, ver:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Please wait...</source>
        <translation>Aguardar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version </source>
        <translation>Versão </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source> in stable repo</source>
        <translation> no Debian Stable Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Not available in stable repo</source>
        <translation>Não disponível no Debian Stable Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source>Latest version </source>
        <translation>Última versão </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source> already installed</source>
        <translation> já instalada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source> installed</source>
        <translation> instalada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>O repositório MX Test, cujos pacotes são disponibilizados apenas para efeito de testagem, está prestes a ser usado. Os pacotes deste repositório podem danificar o sistema, pelo que se sugere que seja feita uma cópia de segurança (backup) do mesmo e que seja instalado ou actualizado apenas um pacote de cada vez. Agradece-se que os resultados sejam comunicados no fórum, para que haja uma avaliação dos pacotes antes de serem movidos para o repositório Main.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Irá ser usado o repositório &apos;Debian Backports&apos;, que contém pacotes retirados da versão &apos;testing&apos; do Debian (próxima versão estável), adaptados e recompilados para uso na actual versão estável do Debian (Debian &apos;stable&apos;), sendo por isso designados de pacotes retro-portados. Estes pacotes não foram tão extensivamente testados como os das versões estáveis do Debian e do MX; são disponibilizados &apos;como estão&apos;, com o risco de incompatibilidades com outros componentes do Debian &apos;stable&apos;. Usar com cuidado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>O MX inclui este repositório de pacotes flatpak apenas para conveniência dos utilizadores, não sendo responsável pelo funcionamento dos próprios pacotes flatpak. Para mais informação (em inglês) consultar &apos;flatpaks&apos; no Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="910"/>
        <source>Do not show this message again</source>
        <translation>Não mostrar esta mensagem novamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Sem ligação à Internet; não será possível descarregar a lista de pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="950"/>
        <source>Installing packages...</source>
        <translation>A instalar pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="993"/>
        <source>Post-processing...</source>
        <translation>Pós-processando... </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1025"/>
        <source>Pre-processing for </source>
        <translation>Pré-processando para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1038"/>
        <source>Installing </source>
        <translation>A instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Post-processing for </source>
        <translation>Pós-processando para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1186"/>
        <source>Downloading package info...</source>
        <translation>A descarregar informação do pacote...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1633"/>
        <source>Packages to be installed: </source>
        <translation>Pacotes a instalar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1671"/>
        <source>Package info</source>
        <translation>Informação do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="1959"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Processing finished successfully.</source>
        <translation>Processamento terminado com êxito.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Detectado problema ao instalar; verificar informação no Terminal/Consola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1828"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1833"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1847"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">Sobre o MX-Instalador de Pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1829"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1830"/>
        <source>Package Installer for MX Linux</source>
        <translation>Gestor de Programas/Pacotes do MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1832"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licença</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registo de alterações</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1876"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1946"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Foi encontrado um problema ao desinstalar. Verificar os resultados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1966"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Houve um problema ao desinstalar o programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak not installed</source>
        <translation>Pacote flatpak não instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>O pacote flatpak não está instalado.
Continuar e instalar o pacote?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak was not installed</source>
        <translation>O pacote flatpak não estava instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote failed</source>
        <translation>Falha no repositório remoto Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote could not be added</source>
        <translation>Não foi possível adicionar o repositório remoto Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>Needs re-login</source>
        <translation>É necessário reentrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Poderá ser necessário sair e reentrar para que os itens fiquem visíveis no menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2280"/>
        <source>Upgrade</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2402"/>
        <source>Quit?</source>
        <translation>Sair?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2403"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Processo ainda em execução. Sair pode deixar o sistema num estado instável.&lt;p&gt;&lt;b&gt;Sair realmente do MX-Instalador de Pacotes?&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gerir repositórios remotos flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Para todos os utilizadores</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Para o presente utilizador</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>introduzir a URL do repositório remoto flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>para instalar uma aplicação, introduzir a localização do respectivo ficheiro .flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Adicionar ou remover repositórios remotos flatpak ou instalar aplicações usando a URL ou o caminho para o respectivo ficheiro .flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Remover repositório remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Adicionar repositório remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Instalar aplicação</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Não removível</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>O Flathub é o principal repositório remoto flatpak e não será removido</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation>Erro ao adicionar o repositório remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Não foi possível adicionar o repositório remoto - o comando resultou num erro. Verificar o endereço do repositório remoto e voltar a tentar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation> Repositório remoto adicionado com êxito</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Unable to get exclusive lock</source>
        <translation>Não foi possível obter o bloqueio exclusivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Está em execução outra aplicação de gestão de pacotes (p. ex. Synaptic ou apt-get). Fechar primeiro a aplicação em execução.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You must run this program as root.</source>
        <translation>Este programa tem que ser executado como root (administrador/superutilizador).</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
</context>
</TS>
